@@ -999,10 +999,10 @@ class HdDB:
         try:
             query = f'SELECT * FROM "{org}__{db}".hd_views WHERE id = ?'
             result = self.execute(query, [id]).fetchdf()
-            return result.to_dict(orient="records")[0]["config"]
+            return result.to_dict(orient="records")[0]
         except duckdb.Error as e:
             raise QueryError(f"Error executing query: {e}")
-    
+
     @attach_motherduck
     def create_geo_table(self, org: str, db: str, tbl: str, df: pd.DataFrame):
         try:
@@ -1015,7 +1015,7 @@ class HdDB:
 
             # Crear la tabla en el esquema actual
             create_query = f'CREATE TABLE "{org}__{db}"."{tbl}" (id VARCHAR, properties JSON, geometry GEOMETRY);'
-            
+
             insert_query = f'INSERT INTO "{org}__{db}"."{tbl}" SELECT id, properties, ST_GeomFromWKB(geometry) FROM df;'
 
             self.execute(create_query)
@@ -1027,7 +1027,7 @@ class HdDB:
         except duckdb.Error as e:
             self.execute("ROLLBACK;")
             raise QueryError(f"Error executing query: {e}")
-        
+
     @attach_motherduck
     def get_geo_table_by_shape(self, org: str, db: str, tbl: str, shape: tuple):
         try:
