@@ -1,3 +1,5 @@
+import random
+import string
 import uuid
 from typing import Dict, List
 
@@ -17,11 +19,17 @@ def generate_field_metadata(df: pd.DataFrame) -> List[Dict[str, str]]:
     """
     metadata = []
     for column in df.columns:
+        if column == "rcd___id":
+            id = "rcd___id"
+        else:
+            letters = "".join([random.choice(string.ascii_letters) for i in range(6)])
+            id = f'{slugify(column, separator="_", regex_pattern=r"[^a-z0-9_]+")}_{letters}'
+
         metadata.append(
             {
-                "fld__id": str(uuid.uuid4()),
+                "fld___id": str(uuid.uuid4()),
                 "label": column,
-                "id": slugify(column, separator="_", regex_pattern=r"[^a-z0-9_]+"),
+                "id": id,
             }
         )
     return metadata
